# Django La Suite

A Django library for the common requirement for the "La Suite numérique" projects.

## Installation

```bash
pip install django-lasuite
```

## Quick Start

To be documented with the first implementations.

## Development

### Requirements

For this project, we use `uv` Python package manager.
Please follow the installation guidelines on the [uv documentation](https://docs.astral.sh/uv/getting-started/installation/).

### Setup

```bash
# Clone the repository
git clone https://github.com/suitenumerique/django-lasuite.git
cd django-lasuite

# Install development dependencies
make install-dev
```

### Testing

```bash
make test
```

### Code Quality

```bash
make lint
```

## License

MIT License
